/*******************************************************************************
* File Name: CAN_RX_INT.c
* Version 1.50
*
* Description:
*  This file contains the Interrupt Service Routine (ISR) for the CAN
*  Component. Interrupt handlers functions generate accordingly to PSoC Creator 
*  Customizer inputs.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CAN_RX.h"

/* `#START CAN_INT_C_CODE_DEFINITION` */

/* `#END` */


#if (CAN_RX_ARB_LOST)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_ArbLost
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Arbitration Lost Interrupt. Clears
    *  Arbitration Lost interrupt flag. Only generated if Arbitration Lost
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    * 
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_ArbLostIsr(void) 
    {
        /* `#START ARBITRATION_LOST_ISR` */

        /* `#END` */
    
        /* Clear Arbitration Lost flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_ARBITRATION_LOST_MASK;
    }
    
#endif /* CAN_RX_ARB_LOST */


#if (CAN_RX_OVERLOAD)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_OvrLdErrror
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Overload Error Interrupt. Clears Overload
    *  Error interrupt flag. Only generated if Overload Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.        
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_OvrLdErrorIsr(void) 
    {
        /* `#START OVER_LOAD_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Overload Error flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_OVERLOAD_ERROR_MASK;
    }
    
#endif /* CAN_RX_OVERLOAD */


#if (CAN_RX_BIT_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_BitError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Error Interrupt. Clears Bit Error
    *  interrupt flag. Only generated if Bit Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_BitErrorIsr(void) 
    {
        /* `#START BIT_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Bit Error flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_BIT_ERROR_MASK;
    }
    
#endif /* CAN_RX_BIT_ERR */


#if (CAN_RX_STUFF_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_BitStuffError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Stuff Error Interrupt. Clears Bit Stuff
    *  Error interrupt flag. Only generated if Bit Stuff Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_BitStuffErrorIsr(void) 
    {
        /* `#START BIT_STUFF_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Stuff Error flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_STUFF_ERROR_MASK;
    }
    
#endif /* CAN_RX_STUFF_ERR */


#if (CAN_RX_ACK_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_AckErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Acknowledge Error Interrupt. Clears
    *  Acknowledge Error interrupt flag. Only generated if Acknowledge Error
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_AckErrorIsr(void) 
    {
        /* `#START ACKNOWLEDGE_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Acknoledge Error flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_ACK_ERROR_MASK;
    }
    
#endif /* CAN_RX_ACK_ERR */


#if (CAN_RX_FORM_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_MsgError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Form Error Interrupt. Clears Form Error
    *  interrupt flag. Only generated if Form Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_MsgErrorIsr(void) 
    {
        /* `#START MESSAGE_ERROR_ISR` */

        /* `#END` */
    
        /* Clear Form Error flag */
        CAN_RX_INT_SR_REG.byte[0u] |= CAN_RX_FORM_ERROR_MASK;
    }
    
#endif /* CAN_RX_FORM_ERR */


#if (CAN_RX_CRC_ERR)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_CrcError
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to CRC Error Interrupt. Clears CRC Error
    *  interrupt flag. Only generated if CRC Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_CrcErrorIsr(void) 
    {
        /* `#START CRC_ERROR_ISR` */

        /* `#END` */
    
        /* Clear CRC Error flag */
        CAN_RX_INT_SR_REG.byte[1u] |= CAN_RX_CRC_ERROR_MASK;
    }
    
#endif /* CAN_RX_CRC_ERR */


#if (CAN_RX_BUS_OFF)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_BusOff
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bus Off Interrupt. Places CAN Component
    *  to Stop mode. Only generated if Bus Off Interrupt enable in Customizer.
    *  Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  Disable power to the CAN Core.
    *
    *******************************************************************************/
    void CAN_RX_BusOffIsr(void) 
    {
        /* `#START BUS_OFF_ISR` */

        /* `#END` */
    
        /* Clear Bus Off flag */
        CAN_RX_INT_SR_REG.byte[1u] |= CAN_RX_BUS_OFF_MASK;
        CAN_RX_Stop();
    }
    
#endif /* CAN_RX_BUS_OFF */


#if (CAN_RX_RX_MSG_LOST)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_MsgLost
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Message Lost Interrupt. Clears Message Lost
    *  interrupt flag. Only generated if Message Lost Interrupt enable in Customizer
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_MsgLostIsr(void) 
    {
        /* `#START MESSAGE_LOST_ISR` */

        /* `#END` */
    
        /* Clear Receive Message Lost flag */
        CAN_RX_INT_SR_REG.byte[1u] |= CAN_RX_RX_MSG_LOST_MASK;
    }
    
#endif /* CAN_RX_RX_MSG_LOST */


#if (CAN_RX_TX_MESSAGE)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_MsgTXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Transmit Message Interrupt. Clears Transmit
    *  Message interrupt flag. Only generated if Transmit Message Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.    
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void CAN_RX_MsgTXIsr(void) 
    {
        /* Clear Transmit Message flag */
        CAN_RX_INT_SR_REG.byte[1u] |= CAN_RX_TX_MESSAGE_MASK;
        
        /* `#START MESSAGE_TRANSMITTED_ISR` */

        /* `#END` */
    }
    
#endif /* CAN_RX_TX_MESSAGE */


#if (CAN_RX_RX_MESSAGE)

    /*******************************************************************************
    * FUNCTION NAME:   CAN_RX_MsgRXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Receive Message Interrupt. Clears Receive
    *  Message interrupt flag and call appropriate handlers for Basic and Full
    *  interrupt based mailboxes. Only generated if Receive Message Interrupt
    *  enable in Customizer. Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void CAN_RX_MsgRXIsr(void) 
    {
        uint8 i;
        uint16 shift = 0x01;
    
        /* Clear Receive Message flag */
        CAN_RX_INT_SR_REG.byte[1u] |= CAN_RX_RX_MESSAGE_MASK;
        
        /* `#START MESSAGE_RECEIVE_ISR` */

        /* `#END` */
    
        for (i = 0u; i < CAN_RX_NUMBER_OF_RX_MAILBOXES; i++)
        {
            if ((CY_GET_REG16((reg16 *) &CAN_RX_BUF_SR_REG.byte[0u]) & shift) == shift)
            {
                if ((CAN_RX_RX[i].rxcmd.byte[0u] & CAN_RX_RX_INT_ENABLE_MASK) ==
                    CAN_RX_RX_INT_ENABLE_MASK)
                {
                    if ((CAN_RX_RX_MAILBOX_TYPE & shift) == shift)
                    {
                        /* RX Full mailboxes handler */
                        switch(i)
                        {
    						case 0 : CAN_RX_ReceiveMsgRX_Message();
							break;
 
                            default:
                                break;
                        }
    
                    }
                    else
                    {
                        /* RX Basic mailbox handler */
                        CAN_RX_ReceiveMsg(i);
                    }
                }
            }
            shift <<= 1u;
        }            
    }
    
#endif /* CAN_RX_RX_MESSAGE */


/*******************************************************************************
* Function Name: CAN_RX_ISR
********************************************************************************
*
* Summary:
*  This ISR is executed when CAN core generate interrupt on one of events:
*  Arb_lost, Overload, Bit_err, Stuff_err, Ack_err, Form_err, Crc_err,
*  Buss_off, Rx_msg_lost, Tx_msg or Rx_msg. The interrupt sources depends
*  on Customizer inputs.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
CY_ISR(CAN_RX_ISR)
{
    /* Arbitration */
    #if (CAN_RX_ARB_LOST)    
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_ARBITRATION_LOST_MASK) ==
             CAN_RX_ARBITRATION_LOST_MASK)
        {
            CAN_RX_ArbLostIsr();
        } 
    #endif /* CAN_RX_ARB_LOST */
    
    /* Overload Error */
    #if (CAN_RX_OVERLOAD)
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_OVERLOAD_ERROR_MASK) ==
             CAN_RX_OVERLOAD_ERROR_MASK)
        {
            CAN_RX_OvrLdErrorIsr();
        }
    #endif /* CAN_RX_OVERLOAD */
    
    /* Bit Error */
    #if (CAN_RX_BIT_ERR)
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_BIT_ERROR_MASK) == CAN_RX_BIT_ERROR_MASK)
        {
            CAN_RX_BitErrorIsr();
        }
    #endif /* CAN_RX_BIT_ERR */
    
    /* Bit Staff Error */
    #if (CAN_RX_STUFF_ERR)
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_STUFF_ERROR_MASK) ==
             CAN_RX_STUFF_ERROR_MASK)
        {
            CAN_RX_BitStuffErrorIsr();
        }
    #endif /* CAN_RX_STUFF_ERR */
    
    /* ACK Error */
    #if (CAN_RX_ACK_ERR)
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_ACK_ERROR_MASK) ==
             CAN_RX_ACK_ERROR_MASK)
        {
            CAN_RX_AckErrorIsr();
        }
    #endif /* CAN_RX_ACK_ERR */
    
    /* Form(msg) Error */
    #if (CAN_RX_FORM_ERR)
        if ((CAN_RX_INT_SR_REG.byte[0u] & CAN_RX_FORM_ERROR_MASK) ==
             CAN_RX_FORM_ERROR_MASK)
        {
            CAN_RX_MsgErrorIsr();
        }
    #endif /* CAN_RX_FORM_ERR */
    
    /* CRC Error */
    #if (CAN_RX_CRC_ERR)
        if ((CAN_RX_INT_SR_REG.byte[1u] & CAN_RX_CRC_ERROR_MASK) == CAN_RX_CRC_ERROR_MASK)
        {
            CAN_RX_CrcErrorIsr();
        }
    #endif /* CAN_RX_CRC_ERR */
    
    /* Bus Off state */
    #if (CAN_RX_BUS_OFF)
        if ((CAN_RX_INT_SR_REG.byte[1u] & CAN_RX_BUS_OFF_MASK) == CAN_RX_BUS_OFF_MASK)
        {
            CAN_RX_BusOffIsr();
        }
    #endif /* CAN_RX_BUS_OFF */
    
    /* Message Lost */
    #if (CAN_RX_RX_MSG_LOST)
        if ((CAN_RX_INT_SR_REG.byte[1u] & CAN_RX_RX_MSG_LOST_MASK) ==
             CAN_RX_RX_MSG_LOST_MASK)
        {
            CAN_RX_MsgLostIsr();
        }
    #endif /* CAN_RX_RX_MSG_LOST */
    
    /* TX Message Send */
    #if (CAN_RX_TX_MESSAGE)
        if ((CAN_RX_INT_SR_REG.byte[1u] & CAN_RX_TX_MESSAGE_MASK) ==
             CAN_RX_TX_MESSAGE_MASK)
        {
            CAN_RX_MsgTXIsr();
        }
    #endif /* CAN_RX_TX_MESSAGE */
    
    /* RX Message Available */
    #if (CAN_RX_RX_MESSAGE)
        if ((CAN_RX_INT_SR_REG.byte[1u] & CAN_RX_RX_MESSAGE_MASK) ==
             CAN_RX_RX_MESSAGE_MASK)
        {
            CAN_RX_MsgRXIsr();
        }
    #endif /* CAN_RX_RX_MESSAGE */
    
    /* PSoC3 ES1, ES2 CAN_RX ISR PATCH  */     
    #if(CAN_RX_PSOC3_ES2 && (CAN_RX_isr__ES2_PATCH))
        CAN_RX_ISR_PATCH();
    #endif /* End CAN_RX_PSOC3_ES2*/       
}


/* [] END OF FILE */
