/*******************************************************************************
* File Name: CAN_RX.h
* Version 1.50
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the CAN Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CAN_CAN_RX_H)
#define CY_CAN_CAN_RX_H

#include "cyfitter.h"
#include "CyLib.h"


/* PSoC3 ES2 or early */
#define CAN_RX_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                                     
#if(CAN_RX_PSOC3_ES2 && (CAN_RX_isr__ES2_PATCH))
    #include <intrins.h>
    #define CAN_RX_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End PSOC3_ES2 */


/***************************************
*       Memory Type Definitions
***************************************/

#if defined(__C51__) || defined(__CX51__)
    #ifndef CYCODE
        #define CYCODE code
    #endif /* End CYCODE */    
#else
    #ifndef CYCODE
        #define CYCODE
    #endif /* End CYCODE */    
#endif /* End __C51__ */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define CAN_RX_ARB_LOST          (0u)
#define CAN_RX_OVERLOAD          (0u)
#define CAN_RX_BIT_ERR           (0u)
#define CAN_RX_STUFF_ERR         (0u)
#define CAN_RX_ACK_ERR           (0u)
#define CAN_RX_FORM_ERR          (0u)
#define CAN_RX_CRC_ERR           (0u)
#define CAN_RX_BUS_OFF           (1u)
#define CAN_RX_RX_MSG_LOST       (0u)
#define CAN_RX_TX_MESSAGE        (0u)
#define CAN_RX_RX_MESSAGE        (1u)

/* TX/RX Function Enable */
#define CAN_RX_TX0_FUNC_ENABLE 0u
#define CAN_RX_TX1_FUNC_ENABLE 0u
#define CAN_RX_TX2_FUNC_ENABLE 0u
#define CAN_RX_TX3_FUNC_ENABLE 0u
#define CAN_RX_TX4_FUNC_ENABLE 0u
#define CAN_RX_TX5_FUNC_ENABLE 0u
#define CAN_RX_TX6_FUNC_ENABLE 0u
#define CAN_RX_TX7_FUNC_ENABLE 0u
#define CAN_RX_RX0_FUNC_ENABLE 1u
#define CAN_RX_RX1_FUNC_ENABLE 0u
#define CAN_RX_RX2_FUNC_ENABLE 0u
#define CAN_RX_RX3_FUNC_ENABLE 0u
#define CAN_RX_RX4_FUNC_ENABLE 0u
#define CAN_RX_RX5_FUNC_ENABLE 0u
#define CAN_RX_RX6_FUNC_ENABLE 0u
#define CAN_RX_RX7_FUNC_ENABLE 0u
#define CAN_RX_RX8_FUNC_ENABLE 0u
#define CAN_RX_RX9_FUNC_ENABLE 0u
#define CAN_RX_RX10_FUNC_ENABLE 0u
#define CAN_RX_RX11_FUNC_ENABLE 0u
#define CAN_RX_RX12_FUNC_ENABLE 0u
#define CAN_RX_RX13_FUNC_ENABLE 0u
#define CAN_RX_RX14_FUNC_ENABLE 0u
#define CAN_RX_RX15_FUNC_ENABLE 0u
#define CAN_RX_RX_MAILBOX_TYPE	0x1u
#define CAN_RX_TX_MAILBOX_TYPE	0x0u



/***************************************
*        Data Struct Definition
***************************************/

/* Stuct for DATA of BASIC CAN */
typedef struct _CAN_RX_dataBytesMsg
{
    uint8 byte[8u];
} CAN_RX_DATA_BYTES_MSG;

/* Stuct for DATA of CAN RX register */
typedef struct _CAN_RX_dataBytes
{
    reg8 byte[8u];
} CAN_RX_DATA_BYTES;

/* Stuct for 32-bit CAN register */
typedef struct _CAN_RX_reg32
{
    reg8 byte[4u];
} CAN_RX_REG_32;

/* Stuct for BASIC CAN to send messages */
typedef struct _CAN_RX_txMsg
{
    uint32 id;
    uint8 rtr;
    uint8 ide;
    uint8 dlc;
    uint8 irq;
    CAN_RX_DATA_BYTES_MSG *msg;
} CAN_RX_TX_MSG;

/* Constant configutaion of CAN RX */
typedef struct _CAN_RX_rxCfg
{
    uint8 rxmailbox;
    uint32 rxcmd;
    uint32 rxamr;
    uint32 rxacr;
} CAN_RX_RX_CFG;

/* Constant configutaion of CAN TX */
typedef struct _CAN_RX_txCfg
{
    uint8 txmailbox;
    uint32 txcmd;
    uint32 txid;
} CAN_RX_TX_CFG;

/* CAN RX registers */
typedef struct _CAN_RX_rxStruct
{
    CAN_RX_REG_32 rxcmd;
    CAN_RX_REG_32 rxid;
    CAN_RX_DATA_BYTES rxdata;
    CAN_RX_REG_32 rxamr;
    CAN_RX_REG_32 rxacr;
    CAN_RX_REG_32 rxamrd;
    CAN_RX_REG_32 rxacrd;
} CAN_RX_RX_STRUCT;

/* CAN TX registers */
typedef struct _CAN_RX_txStruct
{
    CAN_RX_REG_32 txcmd;
    CAN_RX_REG_32 txid;
    CAN_RX_DATA_BYTES txdata;
} CAN_RX_TX_STRUCT;

/* Sleep Mode API Support */
typedef struct _CAN_RX_backupStruct
{
    uint8  enableState;
	uint32 intSr;
    uint32 intEn;
    uint32 cmd;
    uint32 cfg;    
} CAN_RX_BACKUP_STRUCT;

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects
*/
#define CAN_reg32      CAN_RX_REG_32
#define CANTXMsg       CAN_RX_TX_MSG
#define CANRXcfg       CAN_RX_RX_CFG
#define CANTXcfg       CAN_RX_TX_CFG
#define CANRXstruct    CAN_RX_RX_STRUCT
#define CANTXstruct    CAN_RX_TX_STRUCT
#define DATA_BYTES     CAN_RX_DATA_BYTES
#define DATA_BYTES_MSG CAN_RX_DATA_BYTES_MSG


/***************************************
*        Function Prototypes
***************************************/

uint8 CAN_RX_Init(void) ;
uint8 CAN_RX_Start(void);
uint8 CAN_RX_Stop(void) ;
uint8 CAN_RX_Enable(void) ;
uint8 CAN_RX_GlobalIntEnable(void) ;
uint8 CAN_RX_GlobalIntDisable(void) ;
uint8 CAN_RX_SetPreScaler(uint16 bitrate) ;
uint8 CAN_RX_SetArbiter(uint8 arbiter) ;
uint8 CAN_RX_SetTsegSample(uint8 cfgTseg1, uint8 cfgTseg2, uint8 sjw, uint8 sm)
                                                ;
uint8 CAN_RX_SetRestartType(uint8 reset) ;
uint8 CAN_RX_SetEdgeMode(uint8 edge) ;
uint8 CAN_RX_SetOpMode(uint8 opMode) ;
uint8 CAN_RX_RXRegisterInit(reg32 *regAddr, uint32 config)
                                            ;
uint8 CAN_RX_SetIrqMask(uint16 mask) ;
uint8 CAN_RX_GetTXErrorFlag(void) ;
uint8 CAN_RX_GetRXErrorFlag(void) ;
uint8 CAN_RX_GetTXErrorCount(void) ;
uint8 CAN_RX_GetRXErrorCount(void) ;
uint8 CAN_RX_GetErrorState(void) ;
void  CAN_RX_Sleep(void);
void  CAN_RX_Wakeup(void) ;
void  CAN_RX_SaveConfig(void);
void  CAN_RX_RestoreConfig(void) ;

#if (CAN_RX_ARB_LOST)
    void CAN_RX_ArbLostIsr(void) ;
#endif /* CAN_RX_ARB_LOST */

#if (CAN_RX_OVERLOAD)
    void CAN_RX_OvrLdErrorIsr(void) ;
#endif /* CAN_RX_OVERLOAD */

#if (CAN_RX_BIT_ERR)
    void CAN_RX_BitErrorIsr(void) ;
#endif /* CAN_RX_BIT_ERR */

#if (CAN_RX_STUFF_ERR)
    void CAN_RX_BitStuffErrorIsr(void) ;
#endif /* CAN_RX_STUFF_ERR */

#if (CAN_RX_ACK_ERR)
    void CAN_RX_AckErrorIsr(void) ;
#endif /* CAN_RX_ACK_ERR */

#if (CAN_RX_FORM_ERR)
    void CAN_RX_MsgErrorIsr(void) ;
#endif /* CAN_RX_FORM_ERR */

#if (CAN_RX_CRC_ERR)
    void CAN_RX_CrcErrorIsr(void) ;
#endif /* CAN_RX_CRC_ERR */

#if (CAN_RX_BUS_OFF)
    void CAN_RX_BusOffIsr(void) ;
#endif /* CAN_RX_BUS_OFF */

#if (CAN_RX_RX_MSG_LOST)
    void CAN_RX_MsgLostIsr(void) ;
#endif /* CAN_RX_RX_MSG_LOST */

#if (CAN_RX_TX_MESSAGE)
   void CAN_RX_MsgTXIsr(void) ;
#endif /* CAN_RX_TX_MESSAGE */

#if (CAN_RX_RX_MESSAGE)
    void CAN_RX_MsgRXIsr(void) ;
#endif /* CAN_RX_RX_MESSAGE */

uint8 CAN_RX_RxBufConfig(CAN_RX_RX_CFG *rxConfig) ;
uint8 CAN_RX_TxBufConfig(CAN_RX_TX_CFG *txConfig) ;
uint8 CAN_RX_SendMsg(CAN_RX_TX_MSG *message) ;
void  CAN_RX_TxCancel(uint8 bufferId) ;
void  CAN_RX_ReceiveMsg(uint8 rxMailbox) ;

#if (CAN_RX_TX0_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg0(void) ;
#endif /* CAN_RX_TX0_FUNC_ENABLE */

#if (CAN_RX_TX1_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg1(void) ;
#endif /* CAN_RX_TX1_FUNC_ENABLE */

#if (CAN_RX_TX2_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg2(void) ;
#endif /* CAN_RX_TX2_FUNC_ENABLE */

#if (CAN_RX_TX3_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg3(void) ;
#endif /* CAN_RX_TX3_FUNC_ENABLE */

#if (CAN_RX_TX4_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg4(void) ;
#endif /* CAN_RX_TX4_FUNC_ENABLE */

#if (CAN_RX_TX5_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg5(void) ;
#endif /* CAN_RX_TX5_FUNC_ENABLE */

#if (CAN_RX_TX6_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg6(void) ;
#endif /* CAN_RX_TX6_FUNC_ENABLE */

#if (CAN_RX_TX7_FUNC_ENABLE)
    uint8 CAN_RX_SendMsg7(void) ;
#endif /* CAN_RX_TX7_FUNC_ENABLE */

#if (CAN_RX_RX0_FUNC_ENABLE)
    void CAN_RX_ReceiveMsgRX_Message(void) ;
#endif /* CAN_RX_RX0_FUNC_ENABLE */

#if (CAN_RX_RX1_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg1(void) ;
#endif /* CAN_RX_RX1_FUNC_ENABLE */

#if (CAN_RX_RX2_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg2(void) ;
#endif /* CAN_RX_RX2_FUNC_ENABLE */

#if (CAN_RX_RX3_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg3(void) ;
#endif /* CAN_RX_RX3_FUNC_ENABLE */

#if (CAN_RX_RX4_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg4(void) ;
#endif /* CAN_RX_RX4_FUNC_ENABLE */

#if (CAN_RX_RX5_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg5(void) ;
#endif /* CAN_RX_RX5_FUNC_ENABLE */

#if (CAN_RX_RX6_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg6(void) ;
#endif /* CAN_RX_RX6_FUNC_ENABLE */

#if (CAN_RX_RX7_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg7(void) ;
#endif /* CAN_RX_RX7_FUNC_ENABLE */

#if (CAN_RX_RX8_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg8(void) ;
#endif /* CAN_RX_RX8_FUNC_ENABLE */

#if (CAN_RX_RX9_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg9(void) ;
#endif /* CAN_RX_RX9_FUNC_ENABLE */

#if (CAN_RX_RX10_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg10(void) ;
#endif /* CAN_RX_RX10_FUNC_ENABLE */

#if (CAN_RX_RX11_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg11(void) ;
#endif /* CAN_RX_RX11_FUNC_ENABLE */

#if (CAN_RX_RX12_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg12(void) ;
#endif /* CAN_RX_RX12_FUNC_ENABLE */

#if (CAN_RX_RX13_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg13(void) ;
#endif /* CAN_RX_RX13_FUNC_ENABLE */

#if (CAN_RX_RX14_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg14(void) ;
#endif /* CAN_RX_RX14_FUNC_ENABLE */

#if (CAN_RX_RX15_FUNC_ENABLE)
    void CAN_RX_ReceiveMsg15(void) ;
#endif /* CAN_RX_RX15_FUNC_ENABLE */

/* Interrupt handler */
CY_ISR_PROTO(CAN_RX_ISR);


/***************************************
*           API Constants
***************************************/

/* Number of the CAN_RX_isr interrupt */
#define CAN_RX_ISR_NUMBER                 (CAN_RX_isr__INTC_NUMBER)

/* Priority of the CAN_RX_isr interrupt */
#define CAN_RX_ISR_PRIORITY               (CAN_RX_isr__INTC_PRIOR_NUM)

/* One or more parameters to the function were invalid. */
#define CAN_RX_FAIL                       (0x01u)
#define CAN_RX_OUT_OF_RANGE               (0x02u)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects
*/
#define FAIL                                        CAN_RX_FAIL
#define OUT_OF_RANGE                                CAN_RX_OUT_OF_RANGE

/* PM_ACT_CFG (Active Power Mode CFG Register) */
#define CAN_RX_ACT_PWR_EN                 CAN_RX_CanIP__PM_ACT_MSK    /* Power enable mask */

/* PM_STBY_CFG (Alternate Active (Standby) Power Mode CFG Register) */
#define CAN_RX_STBY_PWR_EN                CAN_RX_CanIP__PM_STBY_MSK   /* Power enable mask */

/* Number of TX and RX mailboxes */
#define CAN_RX_NUMBER_OF_TX_MAILBOXES     (8u)
#define CAN_RX_NUMBER_OF_RX_MAILBOXES     (16u) 

/* Error status of CAN */
#define CAN_RX_ERROR_ACTIVE               (0x00u)
#define CAN_RX_ERROR_PASIVE               (0x01u)
#define CAN_RX_ERROR_BUS_OFF              (0x10u)


/***************************************
*    Enumerated Types and Parameters
***************************************/


/***************************************
*    Initial Parameter Constants
***************************************/

/* General */
#define CAN_RX_BITRATE           (2u)
#define CAN_RX_CFG_REG_TSEG1     (13u - 1u)
#define CAN_RX_CFG_REG_TSEG2     (2u - 1u)
#define CAN_RX_CFG_REG_SJW       (1u - 1u)
#define CAN_RX_SAMPLING_MODE     (0u)

#define CAN_RX_ARBITER           (0u)
#define CAN_RX_RESET_TYPE        (1u)
#define CAN_RX_SYNC_EDGE         (0u)

/* Interrupts */
#define CAN_RX_INT_ENABLE        (1u)
#define CAN_RX_INIT_INTERRUPT_MASK ((CAN_RX_INT_ENABLE) | \
                                              (CAN_RX_ARB_LOST << CAN_RX_ARBITRATION_LOST_SHIFT) | \
                                              (CAN_RX_OVERLOAD << CAN_RX_OVERLOAD_ERROR_SHIFT) | \
                                              (CAN_RX_BIT_ERR  << CAN_RX_BIT_ERROR_SHIFT) | \
                                              (CAN_RX_STUFF_ERR << CAN_RX_STUFF_ERROR_SHIFT) | \
                                              (CAN_RX_ACK_ERR   << CAN_RX_ACK_ERROR_SHIFT) | \
                                              (CAN_RX_FORM_ERR  << CAN_RX_FORM_ERROR_SHIFT) | \
                                              (CAN_RX_CRC_ERR   << (CAN_RX_ONE_BYTE_OFFSET + \
                                                                            CAN_RX_CRC_ERROR_SHIFT)) | \
                                              (CAN_RX_BUS_OFF   << (CAN_RX_ONE_BYTE_OFFSET + \
                                                                            CAN_RX_BUS_OFF_SHIFT)) | \
                                              (CAN_RX_RX_MSG_LOST << (CAN_RX_ONE_BYTE_OFFSET + \
                                                                                CAN_RX_RX_MSG_LOST_SHIFT)) | \
                                              (CAN_RX_TX_MESSAGE  << (CAN_RX_ONE_BYTE_OFFSET + \
                                                                           CAN_RX_TX_MESSAGE_SHIFT)) | \
                                              (CAN_RX_RX_MESSAGE  << (CAN_RX_ONE_BYTE_OFFSET + \
                                                                           CAN_RX_RX_MESSAGE_SHIFT)))


/***************************************
*             Registers
***************************************/

#define CAN_RX_TX         ( (volatile CAN_RX_TX_STRUCT XDATA *) CAN_RX_CanIP__TX0_CMD )
#define CAN_RX_RX         ( (volatile CAN_RX_RX_STRUCT XDATA *) CAN_RX_CanIP__RX0_CMD )
#define CAN_RX_INT_SR_REG ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_INT_SR )
#define CAN_RX_INT_SR_PTR (  (reg32 *) CAN_RX_CanIP__CSR_INT_SR )
#define CAN_RX_INT_EN_REG ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_INT_EN )
#define CAN_RX_INT_EN_PTR (  (reg32 *) CAN_RX_CanIP__CSR_INT_EN )
#define CAN_RX_BUF_SR_REG ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_BUF_SR )
#define CAN_RX_BUF_SR_PTR (  (reg32 *) CAN_RX_CanIP__CSR_BUF_SR )
#define CAN_RX_ERR_SR_REG ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_ERR_SR )
#define CAN_RX_ERR_SR_PTR (  (reg32 *) CAN_RX_CanIP__CSR_ERR_SR )
#define CAN_RX_CMD_REG    ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_CMD )
#define CAN_RX_CMD_PTR    (  (reg32 *) CAN_RX_CanIP__CSR_CMD )
#define CAN_RX_CFG_REG    ( *(volatile CAN_RX_REG_32 XDATA *) CAN_RX_CanIP__CSR_CFG )
#define CAN_RX_CFG_PTR    (  (reg32 *) CAN_RX_CanIP__CSR_CFG )
#define CAN_RX_PM_ACT_CFG_REG  ( *(reg8 *) CAN_RX_CanIP__PM_ACT_CFG )    /* Power manager */
#define CAN_RX_PM_ACT_CFG_PTR  (  (reg8 *) CAN_RX_CanIP__PM_ACT_CFG )    /* Power manager */
#define CAN_RX_PM_STBY_CFG_REG ( *(reg8 *) CAN_RX_CanIP__PM_STBY_CFG )   /* Power manager */
#define CAN_RX_PM_STBY_CFG_PTR (  (reg8 *) CAN_RX_CanIP__PM_STBY_CFG )   /* Power manager */

#define CAN_RX_RX_FIRST_REGISTER_PTR    ( (reg32 *) CAN_RX_CanIP__RX0_CMD)
#define CAN_RX_RX_LAST_REGISTER_PTR     ( (reg32 *) CAN_RX_CanIP__RX15_ACRD)

/* Following definitions are for version Compatibility, they are obsolete.
*  Please do not use it in new projects 
*/
#define CAN_RX_INT_SR CAN_RX_INT_SR_REG
#define CAN_RX_INT_EN CAN_RX_INT_EN_REG
#define CAN_RX_BUF_SR CAN_RX_BUF_SR_REG
#define CAN_RX_ERR_SR CAN_RX_ERR_SR_REG
#define CAN_RX_PWRMGR CAN_RX_PM_ACT_CFG_REG
#define CAN_RX_CMD CAN_RX_CMD_REG
#define CAN_RX_CFG CAN_RX_CFG_REG


/***************************************
*        Register Constants
***************************************/

/* Operation mode */
#define CAN_RX_ACTIVE_MODE              (0x00u)
#define CAN_RX_LISTEN_ONLY              (0x01u)

/* Run/Stop mode */
#define CAN_RX_MODE_STOP                (0x00u)
#define CAN_RX_MODE_START               (0x01u)

/* Transmit buffer arbiter */
#define CAN_RX_ROUND_ROBIN              (0x00u)
#define CAN_RX_FIXED_PRIORITY           (0x01u)

/* Restart type */
#define CAN_RX_RESTART_BY_HAND          (0x00u)
#define CAN_RX_AUTO_RESTART             (0x01u)

/* Sampling mode */
#define CAN_RX_ONE_SAMPLE_POINT         (0x00u)
#define CAN_RX_THREE_SAMPLE_POINTS      (0x01u)

/* Edge mode */
#define CAN_RX_EDGE_R_TO_D              (0x00u)
#define CAN_RX_BOTH_EDGES               (0x01u)

/* Extended identifier */
#define CAN_RX_STANDARD_MESSAGE         (0x00u)
#define CAN_RX_EXTENDED_MESSAGE         (0x01u)

/* Write Protect Mask for Basic and Full mailboxes */

#define CAN_RX_TX_WPN_SET               (((uint32)0x00000001u << CAN_RX_TX_WPNL_SHIFT) | \
                                                   ((uint32)0x00000001u << (CAN_RX_TWO_BYTE_OFFSET + \
                                                    CAN_RX_TX_WPNH_SHIFT)))

#define CAN_RX_TX_WPN_CLEAR             (~CAN_RX_TX_WPN_SET)

#define CAN_RX_RX_WPN_SET               (((uint32)0x00000001u << CAN_RX_RX_WPNL_SHIFT) | \
                                                   ((uint32)0x00000001u << (CAN_RX_TWO_BYTE_OFFSET + \
                                                    CAN_RX_RX_WPNH_SHIFT)))

#define CAN_RX_RX_WPN_CLEAR             (~CAN_RX_RX_WPN_SET)

#define CAN_RX_TX_RSVD_MASK             (0x00FF00FFu)

#define CAN_RX_TX_READ_BACK_MASK        (CAN_RX_TX_WPN_CLEAR & CAN_RX_TX_RSVD_MASK)

#define CAN_RX_RX_READ_BACK_MASK        (CAN_RX_RX_WPN_CLEAR & CAN_RX_TX_RSVD_MASK)

#define CAN_RX_RX_CMD_REG_WIDTH         (0x20u)

/* TX send message */
#define CAN_RX_TX_REQUEST_PENDING       (0x01u)
#define CAN_RX_RETRY_NUMBER             (0x03u)
#define CAN_RX_SEND_MESSAGE_SHIFT       (0u)
#define CAN_RX_SEND_MESSAGE             ((uint32)0x00000001u << CAN_RX_SEND_MESSAGE_SHIFT)

/* Offsets to maintain bytes within uint32 */
#define CAN_RX_ONE_BYTE_OFFSET          (8u)
#define CAN_RX_TWO_BYTE_OFFSET          (16u)
#define CAN_RX_TREE_BYTE_OFFSET         (24u)

/* Set/Clear bits macro for CAN_RX_RX maibox(i) */
/* bit 0 within RX_CMD[i] */
#define CAN_RX_RX_ACK_MSG_SHIFT         (0u)
#define CAN_RX_RX_ACK_MSG               (0x01u << CAN_RX_RX_ACK_MSG_SHIFT)
#define CAN_RX_RX_ACK_MESSAGE(i)        CAN_RX_RX[i].rxcmd.byte[0u] |= CAN_RX_RX_ACK_MSG
/* bit 2 within RX_CMD[i] */
#define CAN_RX_RX_RTR_ABORT_SHIFT       (2u)
#define CAN_RX_RX_RTR_ABORT_MASK        (0x01u << CAN_RX_RX_RTR_ABORT_SHIFT)
#define CAN_RX_RX_RTR_ABORT_MESSAGE(i)  CAN_RX_RX[i].rxcmd.byte[0u] |= \
                                                    CAN_RX_RX_RTR_ABORT_MASK
/* bit 3 within RX_CMD[i] */
#define CAN_RX_RX_BUF_ENABLE_SHIFT      (3u)
#define CAN_RX_RX_BUF_ENABLE_MASK       (0x01u << CAN_RX_RX_BUF_ENABLE_SHIFT)
#define CAN_RX_SET_RX_BUF_ENABLE(i)     CAN_RX_RX[i].rxcmd.byte[0u] |= \
                                                    CAN_RX_RX_BUF_ENABLE_MASK
#define CAN_RX_CLEAR_RX_BUF_DISABLE(i)  CAN_RX_RX[i].rxcmd.byte[0u] &= \
                                                    ~CAN_RX_RX_BUF_ENABLE_MASK
/* bit 4 within RX_CMD[i] */
#define CAN_RX_RX_RTRREPLY_SHIFT         (4u)
#define CAN_RX_RX_RTRREPLY_MASK          (0x01u << CAN_RX_RX_RTRREPLY_SHIFT)
#define CAN_RX_SET_RX_RTRREPLY(i)        CAN_RX_RX[i].rxcmd.byte[0u] |= \
                                                    CAN_RX_RX_RTRREPLY_MASK
#define CAN_RX_CLEAR_RX_RTRREPLY(i)      CAN_RX_RX[i].rxcmd.byte[0u] &= \
                                                    ~CAN_RX_RX_RTRREPLY_MASK
/* bit 5 within RX_CMD[i] */
#define CAN_RX_RX_INT_ENABLE_SHIFT      (5u)
#define CAN_RX_RX_INT_ENABLE_MASK       (0x01u << CAN_RX_RX_INT_ENABLE_SHIFT)
#define CAN_RX_RX_INT_ENABLE(i)         CAN_RX_RX[i].rxcmd.byte[0u] |= \
                                                    CAN_RX_RX_INT_ENABLE_MASK
#define CAN_RX_RX_INT_DISABLE(i)        CAN_RX_RX[i].rxcmd.byte[0u] &= \
                                                    ~CAN_RX_RX_INT_ENABLE_MASK
/* bit 6 within RX_CMD[i] */
#define CAN_RX_RX_LINKING_SHIFT         (6u)
#define CAN_RX_RX_LINKING_MASK          (0x01u << CAN_RX_RX_LINKING_SHIFT)
#define CAN_RX_SET_RX_LINKING(i)        CAN_RX_RX[i].rxcmd.byte[0u] |= \
                                                    CAN_RX_RX_LINKING_MASK
#define CAN_RX_CLEAR_RX_LINKING(i)      CAN_RX_RX[i].rxcmd.byte[0u] &= \
                                                    ~CAN_RX_RX_LINKING_MASK
/* bit 7 within RX_CMD[i] */
#define CAN_RX_RX_WPNL_SHIFT           (7u)
#define CAN_RX_RX_WPNL_MASK            (0x01u << CAN_RX_RX_WPNL_SHIFT)
#define CAN_RX_SET_RX_WNPL(i)          CAN_RX_RX[i].rxcmd.byte[0u] |= CAN_RX_RX_WPNL_MASK
#define CAN_RX_CLEAR_RX_WNPL(i)        CAN_RX_RX[i].rxcmd.byte[0u] &= ~CAN_RX_RX_WPNL_MASK
/* bit 23 within RX_CMD[i] */
#define CAN_RX_RX_WPNH_SHIFT           (7u)
#define CAN_RX_RX_WPNH_MASK            (0x01u << CAN_RX_RX_WPNH_SHIFT)
#define CAN_RX_SET_RX_WNPH(i)          CAN_RX_RX[i].rxcmd.byte[2u] |= CAN_RX_RX_WPNH_MASK
#define CAN_RX_CLEAR_RX_WNPH(i)        CAN_RX_RX[i].rxcmd.byte[2u] &= ~CAN_RX_RX_WPNH_MASK

/* bits 19-16 within TX_CMD[i] */
#define CAN_RX_RX_DLC_VALUE_SHIFT      (0u)
#define CAN_RX_RX_DLC_VALUE_MASK       (0x0Fu << CAN_RX_RX_DLC_VALUE_SHIFT)
#define CAN_RX_GET_DLC(mailbox)        (CAN_RX_RX[mailbox].rxcmd.byte[2u] & \
                                                  CAN_RX_RX_DLC_VALUE_MASK)

/* Set/Clear bits macro for CAN_RX_TX mailbox(i) */
/* bit 0 within TX_CMD[i] */
#define CAN_RX_TX_TRANSMIT_REQUEST_SHIFT (0u)
#define CAN_RX_TX_TRANSMIT_REQUEST       (0x01u << CAN_RX_TX_TRANSMIT_REQUEST_SHIFT)
#define CAN_RX_TX_TRANSMIT_MESSAGE(i)    CAN_RX_TX[i].txcmd.byte[0u] |= \
                                                    CAN_RX_TX_TRANSMIT_REQUEST
/* bit 1 within TX_CMD[i] */
#define CAN_RX_TX_ABORT_SHIFT          (1u)
#define CAN_RX_TX_ABORT_MASK           (0x01u << CAN_RX_TX_ABORT_SHIFT)
#define CAN_RX_TX_ABORT_MESSAGE(i)     CAN_RX_TX[i].txcmd.byte[0u] |= CAN_RX_TX_ABORT_MASK
/* bit 2 within TX_CMD[i] */
#define CAN_RX_TRANSMIT_INT_ENABLE     (0x01u)
#define CAN_RX_TRANSMIT_INT_DISABLE    (0x00u)
#define CAN_RX_TX_INT_ENABLE_SHIFT     (2u)
#define CAN_RX_TX_INT_ENABLE_MASK      ((uint32)0x00000001u << CAN_RX_TX_INT_ENABLE_SHIFT)
#define CAN_RX_TX_INT_ENABLE(i)        CAN_RX_TX[i].txcmd.byte[0u] |= \
                                                  CAN_RX_TX_INT_ENABLE_MASK
#define CAN_RX_TX_INT_DISABLE(i)       CAN_RX_TX[i].txcmd.byte[0u] &= \
                                                  ~CAN_RX_TX_INT_ENABLE_MASK
/* bit 3 within TX_CMD[i] */
#define CAN_RX_TX_WPNL_SHIFT           (3u)
#define CAN_RX_TX_WPNL_MASK            (0x01u << CAN_RX_TX_WPNL_SHIFT)
#define CAN_RX_SET_TX_WNPL(i)          CAN_RX_TX[i].txcmd.byte[0u] |= CAN_RX_TX_WPNL_MASK
#define CAN_RX_CLEAR_TX_WNPL(i)        CAN_RX_TX[i].txcmd.byte[0u] &= ~CAN_RX_TX_WPNL_MASK
/* bits 19-16 within TX_CMD[i] */
#define CAN_RX_TX_DLC_VALUE_SHIFT        (0u)
#define CAN_RX_TX_DLC_UPPER_VALUE_SHIFT  (19u)
#define CAN_RX_TX_DLC_UPPER_VALUE        ((uint32)0x00000001u << CAN_RX_TX_DLC_UPPER_VALUE_SHIFT)
#define CAN_RX_TX_DLC_VALUE_MASK         (0x0Fu << CAN_RX_TX_DLC_VALUE_SHIFT)
#define CAN_RX_TX_DLC_MAX_VALUE          (8u)
/* bit 20 within TX_CMD[i] */
#define CAN_RX_TX_IDE_SHIFT             (20u)
#define CAN_RX_TX_IDE_MASK              ((uint32)0x00000001u << CAN_RX_TX_IDE_SHIFT)
#define CAN_RX_SET_TX_IDE(i)            CAN_RX_TX[i].txcmd.byte[2u] |= CAN_RX_TX_IDE_MASK
#define CAN_RX_CLEAR_TX_IDE(i)          CAN_RX_TX[i].txcmd.byte[2u] &= ~CAN_RX_TX_IDE_MASK
/* bit 21 within TX_CMD[i] */
#define CAN_RX_TX_RTR_SHIFT             (21u)
#define CAN_RX_TX_RTR_MASK              ((uint32)0x00000001u <<  CAN_RX_TX_RTR_SHIFT)
#define CAN_RX_SET_TX_RTR(i)            CAN_RX_TX[i].txcmd.byte[2u] |= CAN_RX_TX_RTR_MASK
#define CAN_RX_CLEAR_TX_RTR(i)          CAN_RX_TX[i].txcmd.byte[2u] &= ~CAN_RX_TX_RTR_MASK
/* bit 23 within TX_CMD[i] */
#define CAN_RX_TX_WPNH_SHIFT            (7u)
#define CAN_RX_TX_WPNH_MASK             (0x01u << CAN_RX_TX_WPNH_SHIFT)
#define CAN_RX_SET_TX_WNPH(i)           CAN_RX_TX[i].txcmd.byte[2u] |= CAN_RX_TX_WPN_MASK
#define CAN_RX_CLEAR_TX_WNPH(i)         CAN_RX_TX[i].txcmd.byte[2u] &= ~CAN_RX_TX_WPN_MASK
/* bit 4 within RX_CMD[i].byte[2] */
#define CAN_RX_RX_IDE_SHIFT             (4u)
#define CAN_RX_RX_IDE_MASK              (0x01u << CAN_RX_RX_IDE_SHIFT)
#define CAN_RX_GET_RX_IDE(i)            (CAN_RX_RX[i].rxcmd.byte[2u] & CAN_RX_RX_IDE_MASK)
#define CAN_RX_GET_RX_ID(i)             ((CAN_RX_GET_RX_IDE(i)) ? ((CY_GET_REG32((reg32 *) & \
                                                    CAN_RX_RX[i].rxid)) >> 3u) : ((CY_GET_REG32((reg32 *) & \
                                                    CAN_RX_RX[i].rxid)) >> 21u))

#define CAN_RX_RX_DATA_BYTE(mailbox, i) CAN_RX_RX[mailbox].rxdata.byte[((i) > 3u) ? \
                                                                                         (7u - ((i) - 4u)) : (3u - (i))]
#define CAN_RX_TX_DATA_BYTE(mailbox, i) CAN_RX_TX[mailbox].txdata.byte[((i) > 3u) ? \
                                                                                         (7u - ((i) - 4u)) : (3u - (i))]

/* Macros for access to RX DATA for mailbox(i) */
#define CAN_RX_RX_DATA_BYTE1(i)          CAN_RX_RX[i].rxdata.byte[3u]
#define CAN_RX_RX_DATA_BYTE2(i)          CAN_RX_RX[i].rxdata.byte[2u]
#define CAN_RX_RX_DATA_BYTE3(i)          CAN_RX_RX[i].rxdata.byte[1u]
#define CAN_RX_RX_DATA_BYTE4(i)          CAN_RX_RX[i].rxdata.byte[0u]
#define CAN_RX_RX_DATA_BYTE5(i)          CAN_RX_RX[i].rxdata.byte[7u]
#define CAN_RX_RX_DATA_BYTE6(i)          CAN_RX_RX[i].rxdata.byte[6u]
#define CAN_RX_RX_DATA_BYTE7(i)          CAN_RX_RX[i].rxdata.byte[5u]
#define CAN_RX_RX_DATA_BYTE8(i)          CAN_RX_RX[i].rxdata.byte[4u]

/* Macros for access to TX DATA for mailbox(i) */
#define CAN_RX_TX_DATA_BYTE1(i)          CAN_RX_TX[i].txdata.byte[3u]
#define CAN_RX_TX_DATA_BYTE2(i)          CAN_RX_TX[i].txdata.byte[2u]
#define CAN_RX_TX_DATA_BYTE3(i)          CAN_RX_TX[i].txdata.byte[1u]
#define CAN_RX_TX_DATA_BYTE4(i)          CAN_RX_TX[i].txdata.byte[0u]
#define CAN_RX_TX_DATA_BYTE5(i)          CAN_RX_TX[i].txdata.byte[7u]
#define CAN_RX_TX_DATA_BYTE6(i)          CAN_RX_TX[i].txdata.byte[6u]
#define CAN_RX_TX_DATA_BYTE7(i)          CAN_RX_TX[i].txdata.byte[5u]
#define CAN_RX_TX_DATA_BYTE8(i)          CAN_RX_TX[i].txdata.byte[4u]

/* Macros for set Tx Msg Indentifier in CAN_RX_TX_ID register */
#define CAN_RX_SET_TX_ID_STANDARD_MSG_SHIFT   (21u)
#define CAN_RX_SET_TX_ID_EXTENDED_MSG_SHIFT   (3u)
#define CAN_RX_SET_TX_ID_STANDARD_MSG(i, id)  CY_SET_REG32( (reg32 *) &CAN_RX_TX[i].txid, (id << \
                                                        CAN_RX_SET_TX_ID_STANDARD_MSG_SHIFT) );
#define CAN_RX_SET_TX_ID_EXTENDED_MSG(i, id)  CY_SET_REG32( (reg32 *) &CAN_RX_TX[i].txid, (id << \
                                                        CAN_RX_SET_TX_ID_EXTENDED_MSG_SHIFT) );

/* Mask for bits within CAN_RX_CSR_CFG */
#define CAN_RX_EDGE_MODE_SHIFT           (0u)
/* bit 0 within CSR_CFG */
#define CAN_RX_EDGE_MODE_MASK            (0x01u << CAN_RX_EDGE_MODE_SHIFT)
#define CAN_RX_SAMPLE_MODE_SHIFT         (1u)
/* bit 1 within CSR_CFG */
#define CAN_RX_SAMPLE_MODE_MASK          (0x01u << CAN_RX_SAMPLE_MODE_SHIFT)
#define CAN_RX_CFG_REG_SJW_SHIFT         (2u)
/* bits 3-2 within CSR_CFG */
#define CAN_RX_CFG_REG_SJW_MASK          (0x03u << CAN_RX_CFG_REG_SJW_SHIFT)
#define CAN_RX_CFG_REG_SJW_LOWER_LIMIT   (0x03u)  /* the lowest allowed value of cfg_sjw */
#define CAN_RX_RESET_SHIFT               (4u)
/* bit 4 within CSR_CFG    */
#define CAN_RX_RESET_MASK                (0x01u << CAN_RX_RESET_SHIFT)
#define CAN_RX_CFG_REG_TSEG2_SHIFT       (5u)
/* bits 7-5 within CSR_CFG */
#define CAN_RX_CFG_REG_TSEG2_MASK        (0x07u << CAN_RX_CFG_REG_TSEG2_SHIFT)
/* the highest allowed value of cfg_tseg2 */
#define CAN_RX_CFG_REG_TSEG2_UPPER_LIMIT     (0x07u)
/* the lowest allowed value of cfg_tseg2 */
#define CAN_RX_CFG_REG_TSEG2_LOWER_LIMIT     (0x02u)
 /* the lowest allowed value of cfg_tseg2 if sample point is one point */
#define CAN_RX_CFG_REG_TSEG2_EXCEPTION       (0x01u)  
/* bits 11-8 within CSR_CFG */
#define CAN_RX_CFG_REG_TSEG1_MASK            (0x0Fu)
/* the highest allowed value of cfg_tseg1 */
#define CAN_RX_CFG_REG_TSEG1_UPPER_LIMIT     (0x0Fu)
/* the lowest allowed value of cfg_tseg1 */
#define CAN_RX_CFG_REG_TSEG1_LOWER_LIMIT     (0x02u)
#define CAN_RX_ARBITRATION_SHIFT             (4u)
/* bit 12 within CSR_CFG */
#define CAN_RX_ARBITRATION_MASK              (0x01u << CAN_RX_ARBITRATION_SHIFT)
/* bits 23-16 within CSR_CFG */
#define CAN_RX_BITRATE_MASK                  (0x7FFFu)

/* Mask for bits within CAN_RX_CSR_CMD */
#define CAN_RX_MODE_SHIFT                    (0u)
/* bit 0 within CSR_CMD */
#define CAN_RX_MODE_MASK                     (0x01u << CAN_RX_MODE_SHIFT)
#define CAN_RX_OPMODE_MASK_SHIFT             (1u)
/* bit 1 within CSR_CMD */
#define CAN_RX_OPMODE_MASK                   (0x01u << CAN_RX_OPMODE_MASK_SHIFT)

/* Mask for bits within CAN_RX_CSR_CMD */
#define CAN_RX_ERROR_STATE_SHIFT             (0u)
/* bit 17-16 within ERR_SR */
#define CAN_RX_ERROR_STATE_MASK              (0x03u << CAN_RX_ERROR_STATE_SHIFT)
#define CAN_RX_TX_ERROR_FLAG_SHIFT           (2u)
/* bit 18 within ERR_SR */
#define CAN_RX_TX_ERROR_FLAG_MASK            (0x01u << CAN_RX_TX_ERROR_FLAG_SHIFT)
#define CAN_RX_RX_ERROR_FLAG_SHIFT           (3u)
/* bit 19 within ERR_SR */
#define CAN_RX_RX_ERROR_FLAG_MASK            (0x01u << CAN_RX_RX_ERROR_FLAG_SHIFT)


/* Mask and Macros for bits within CAN_RX_INT_EN_REG */
#define CAN_RX_GLOBAL_INT_SHIFT              (0u)
/* bit 0 within INT_EN */
#define CAN_RX_GLOBAL_INT_MASK               (0x01u << CAN_RX_GLOBAL_INT_SHIFT)
#define CAN_RX_ARBITRATION_LOST_SHIFT        (2u)
/* bit 2 within INT_EN and INT_SR */
#define CAN_RX_ARBITRATION_LOST_MASK         (0x01u << CAN_RX_ARBITRATION_LOST_SHIFT)
#define CAN_RX_ARBITRATION_LOST_INT_ENABLE   CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_ARBITRATION_LOST_MASK
#define CAN_RX_ARBITRATION_LOST_INT_DISABLE  CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_ARBITRATION_LOST_MASK
#define CAN_RX_OVERLOAD_ERROR_SHIFT          (3u)
/* bit 3 within INT_EN and INT_SR */
#define CAN_RX_OVERLOAD_ERROR_MASK           (0x01u << CAN_RX_OVERLOAD_ERROR_SHIFT)
#define CAN_RX_OVERLOAD_ERROR_INT_ENABLE     CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_OVERLOAD_ERROR_MASK
#define CAN_RX_OVERLOAD_ERROR_INT_DISABLE    CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_OVERLOAD_ERROR_MASK
#define CAN_RX_BIT_ERROR_SHIFT               (4u)
/* bit 4 within INT_EN and INT_SR */
#define CAN_RX_BIT_ERROR_MASK                (0x01u << CAN_RX_BIT_ERROR_SHIFT)
#define CAN_RX_BIT_ERROR_LOST_INT_ENABLE     CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_BIT_ERROR_MASK
#define CAN_RX_BIT_ERROR_LOST_INT_DISABLE    CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_BIT_ERROR_MASK
#define CAN_RX_STUFF_ERROR_SHIFT             (5u)
/* bit 5 within INT_EN and INT_SR */
#define CAN_RX_STUFF_ERROR_MASK              (0x01u << CAN_RX_STUFF_ERROR_SHIFT)
#define CAN_RX_STUFF_ERROR_INT_ENABLE        CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_STUFF_ERROR_MASK
#define CAN_RX_STUFF_ERROR_INT_DISABLE       CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_STUFF_ERROR_MASK
#define CAN_RX_ACK_ERROR_SHIFT               (6u)
/* bit 6 within INT_EN and INT_SR */
#define CAN_RX_ACK_ERROR_MASK                (0x01u << CAN_RX_ACK_ERROR_SHIFT)
#define CAN_RX_ACK_ERROR_INT_ENABLE          CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_ACK_ERROR_MASK
#define CAN_RX_ACK_ERROR_INT_DISABLE         CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_ACK_ERROR_MASK
#define CAN_RX_FORM_ERROR_SHIFT              (7u)
/* bit 7 within INT_EN and INT_SR */
#define CAN_RX_FORM_ERROR_MASK               (0x01u << CAN_RX_FORM_ERROR_SHIFT)
#define CAN_RX_FORM_ERROR_INT_ENABLE         CAN_RX_INT_EN_REG.byte[0u] |= \
                                                        CAN_RX_FORM_ERROR_MASK
#define CAN_RX_FORM_ERROR_INT_DISABLE        CAN_RX_INT_EN_REG.byte[0u] &= \
                                                        ~CAN_RX_FORM_ERROR_MASK
#define CAN_RX_CRC_ERROR_SHIFT               (0u)
/* bit 8 within INT_EN and INT_SR */
#define CAN_RX_CRC_ERROR_MASK                (0x01u << CAN_RX_CRC_ERROR_SHIFT)
#define CAN_RX_CRC_ERROR_INT_ENABLE          CAN_RX_INT_EN_REG.byte[1u] |= \
                                                        CAN_RX_CRC_ERROR_MASK
#define CAN_RX_CRC_ERROR_INT_DISABLE         CAN_RX_INT_EN_REG.byte[1u] &= \
                                                        ~CAN_RX_CRC_ERROR_MASK
#define CAN_RX_BUS_OFF_SHIFT                 (1u)
/* bit 9 within INT_EN and INT_SR */
#define CAN_RX_BUS_OFF_MASK                  (0x01u << CAN_RX_BUS_OFF_SHIFT)
#define CAN_RX_BUS_OFF_INT_ENABLE            CAN_RX_INT_EN_REG.byte[1u] |= \
                                                        CAN_RX_BUS_OFF_MASK
#define CAN_RX_BUS_OFF_INT_DISABLE           CAN_RX_INT_EN_REG.byte[1u] &= \
                                                        ~CAN_RX_BUS_OFF_MASK
#define CAN_RX_RX_MSG_LOST_SHIFT             (2u)
/* bit 10 within INT_EN and INT_SR */
#define CAN_RX_RX_MSG_LOST_MASK              (0x01u << CAN_RX_RX_MSG_LOST_SHIFT)
#define CAN_RX_RX_MSG_LOST_INT_ENABLE        CAN_RX_INT_EN_REG.byte[1u] |= \
                                                        CAN_RX_RX_MSG_LOST_MASK
#define CAN_RX_RX_MSG_LOST_INT_DISABLE       CAN_RX_INT_EN_REG.byte[1u] &= \
                                                        ~CAN_RX_RX_MSG_LOST_MASK
#define CAN_RX_TX_MESSAGE_SHIFT              (3u)
/* bit 11 within INT_EN and INT_SR */
#define CAN_RX_TX_MESSAGE_MASK               (0x01u << CAN_RX_TX_MESSAGE_SHIFT)
#define CAN_RX_TX_MSG_INT_ENABLE             CAN_RX_INT_EN_REG.byte[1u] |= \
                                                        CAN_RX_TX_MESSAGE_MASK
#define CAN_RX_TX_MSG_INT_DISABLE            CAN_RX_INT_EN_REG.byte[1u] &= \
                                                        ~CAN_RX_TX_MESSAGE_MASK
#define CAN_RX_RX_MESSAGE_SHIFT              (4u)
/* bit 12 within INT_EN and INT_SR */
#define CAN_RX_RX_MESSAGE_MASK               (0x01u << CAN_RX_RX_MESSAGE_SHIFT)
#define CAN_RX_RX_MSG_INT_ENABLE             CAN_RX_INT_EN_REG.byte[1u] |= \
                                                        CAN_RX_RX_MESSAGE_MASK
#define CAN_RX_RX_MSG_INT_DISABLE            CAN_RX_INT_EN_REG.byte[1u] &= \
                                                        ~CAN_RX_RX_MESSAGE_MASK

#endif /* CY_CAN_CAN_RX_H */


/* [] END OF FILE */
